**Example 1: 停止执行器**



Input: 

```
tccli tat DisableInvoker --cli-unfold-argument  \
    --InvokerId ivk-b7s3qa5l
```

Output: 
```
{
    "Response": {
        "RequestId": "a6c5b0bd-4273-47c0-8d34-c32822f3ccb0"
    }
}
```

